from networkx.classes.graph import Graph, _Node
from networkx.utils.backends import _dispatch

@_dispatch
def degree_centrality(G: Graph[_Node]) -> dict[_Node, float]: ...
@_dispatch
def in_degree_centrality(G: Graph[_Node]) -> dict[_Node, float]: ...
@_dispatch
def out_degree_centrality(G: Graph[_Node]) -> dict[_Node, float]: ...
